diff --git a/asminc/telestrat.inc b/asminc/telestrat.inc
index 7d4c1e31d..79ac2d566 100644
--- a/asminc/telestrat.inc
+++ b/asminc/telestrat.inc
@@ -275,7 +275,7 @@ XFWRITE = $3B ; Only in TELEMON 3.x write file (bank 7 of Orix
; Clock primitive
XRECLK = $3C ; Reset clock
XCLCL = $3D ; Close clock
-XWRCLK = $3E ; Displays clock in the adress in A & Y registers
+XWRCLK = $3E ; Displays clock in the address in A & Y registers
; Sound primitives
XSONPS = $40 ; Send data to PSG register (14 values)
diff --git a/doc/apple2.sgml b/doc/apple2.sgml
index 09052ade1..63b40c6f8 100644
--- a/doc/apple2.sgml
+++ b/doc/apple2.sgml
@@ -370,7 +370,7 @@ The names in the parentheses denote the symbols to be used for static linking of
In memory constrained situations the memory from $803 to $1FFF
can be made available to a program by calling
diff --git a/doc/apple2enh.sgml b/doc/apple2enh.sgml
index a105cb47a..15ceed04f 100644
--- a/doc/apple2enh.sgml
+++ b/doc/apple2enh.sgml
@@ -376,7 +376,7 @@ The names in the parentheses denote the symbols to be used for static linking of
In memory constrained situations the memory from $803 to $1FFF
can be made available to a program by calling
diff --git a/doc/c64.sgml b/doc/c64.sgml
index de37ed4b7..8c1b3754e 100644
--- a/doc/c64.sgml
+++ b/doc/c64.sgml
@@ -126,7 +126,7 @@ and $FF3F.
In memory constrained situations the memory from $400 to $7FF
can be made available to a program by calling ,
Conditional assembly: Check if a symbol is defined. Must be followed by
- a symbol name. The condition is true if the the given symbol is already
+ a symbol name. The condition is true if the given symbol is already
defined, and false otherwise.
See also:
@@ -3143,7 +3143,7 @@ See: ,
Conditional assembly: Check if a symbol is defined. Must be followed by
- a symbol name. The condition is true if the the given symbol is not
+ a symbol name. The condition is true if the given symbol is not
defined, and false otherwise.
See also:
@@ -3152,7 +3152,7 @@ See: ,
Conditional assembly: Check if a symbol is referenced. Must be followed
- by a symbol name. The condition is true if if the the given symbol was
+ by a symbol name. The condition is true if if the given symbol was
not referenced before, and false otherwise.
See also:
@@ -3197,7 +3197,7 @@ See: ,
Conditional assembly: Check if a symbol is referenced. Must be followed
- by a symbol name. The condition is true if if the the given symbol was
+ by a symbol name. The condition is true if if the given symbol was
referenced before, and false otherwise.
This command may be used to build subroutine libraries in include files
diff --git a/doc/funcref.sgml b/doc/funcref.sgml
index 1a9dcaa77..a8593ebb5 100644
--- a/doc/funcref.sgml
+++ b/doc/funcref.sgml
@@ -6127,7 +6127,7 @@ pointer you're passing somewhere else, otherwise
ptr = realloc (ptr, size);
-will loose your only copy of The function is only available as fastcall function, so it may only
be used in presence of a prototype.
diff --git a/include/_atarios.h b/include/_atarios.h
index 5e1374fa5..986092659 100644
--- a/include/_atarios.h
+++ b/include/_atarios.h
@@ -105,7 +105,7 @@ struct __dos2x {
unsigned char* zbufp; /* points to user filename */
unsigned char* zdrva; /* points to serveral buffers (mostly VTOC) */
unsigned char* zsba; /* points to sector buffer */
- unsigned char errno; /* number of occured error */
+ unsigned char errno; /* number of occurred error */
};
typedef struct __dos2x dos2x_t;
diff --git a/include/cc65.h b/include/cc65.h
index 7e9c2cae2..2b05cc17a 100644
--- a/include/cc65.h
+++ b/include/cc65.h
@@ -59,21 +59,21 @@ unsigned long __fastcall__ udiv32by16r16 (unsigned long rhs, unsigned lhs);
*/
int __fastcall__ imul8x8r16 (signed char lhs, signed char rhs);
-/* Multiplicate two signed 8 bit to yield an signed 16 bit result */
+/* Multiply two signed 8 bit to yield an signed 16 bit result */
long __fastcall__ imul16x16r32 (int lhs, int rhs);
-/* Multiplicate two signed 16 bit to yield a signed 32 bit result */
+/* Multiply two signed 16 bit to yield a signed 32 bit result */
unsigned __fastcall__ umul8x8r16 (unsigned char lhs, unsigned char rhs);
-/* Multiplicate two unsigned 8 bit to yield an unsigned 16 bit result */
+/* Multiply two unsigned 8 bit to yield an unsigned 16 bit result */
unsigned long __fastcall__ umul16x8r32 (unsigned lhs, unsigned char rhs);
-/* Multiplicate an unsigned 16 bit by an unsigned 8 bit number yielding a 24
+/* Multiply an unsigned 16 bit by an unsigned 8 bit number yielding a 24
** bit unsigned result that is extended to 32 bits for easier handling from C.
*/
unsigned long __fastcall__ umul16x16r32 (unsigned lhs, unsigned rhs);
-/* Multiplicate two unsigned 16 bit to yield an unsigned 32 bit result */
+/* Multiply two unsigned 16 bit to yield an unsigned 32 bit result */
unsigned int __fastcall__ mul20 (unsigned char value);
/* Multiply an 8 bit unsigned value by 20 and return the 16 bit unsigned
diff --git a/libsrc/apple2/exec.s b/libsrc/apple2/exec.s
index c0cd98650..9212ecb8a 100644
--- a/libsrc/apple2/exec.s
+++ b/libsrc/apple2/exec.s
@@ -129,7 +129,7 @@ setbuf: lda #$00 ; Low byte
.assert MLI::OPEN::PATHNAME = MLI::INFO::PATHNAME, error
; Lower file level to avoid program file
- ; being closed by C libary shutdown code
+ ; being closed by C library shutdown code
ldx LEVEL
stx level
beq :+
@@ -185,13 +185,13 @@ setbuf: lda #$00 ; Low byte
lda #$00 ; '\0'
beq :- ; Branch always
- ; Call loader stub after C libary shutdown
+ ; Call loader stub after C library shutdown
: lda #target
sta done+1
stx done+2
- ; Initiate C libary shutdown
+ ; Initiate C library shutdown
jmp _exit
.bss
diff --git a/libsrc/c128/emd/c128-reu.s b/libsrc/c128/emd/c128-reu.s
index 3ded00d67..84e7cb695 100644
--- a/libsrc/c128/emd/c128-reu.s
+++ b/libsrc/c128/emd/c128-reu.s
@@ -72,7 +72,7 @@ reu_params: .word $0000 ; Host address, lo, hi
.byte $00 ; Expansion bank no.
.word $0000 ; # bytes to move, lo, hi
.byte $00 ; Interrupt mask reg.
- .byte $00 ; Adress control reg.
+ .byte $00 ; Address control reg.
.code
diff --git a/libsrc/c64/emd/c64-reu.s b/libsrc/c64/emd/c64-reu.s
index a563305ce..07ac1fbed 100644
--- a/libsrc/c64/emd/c64-reu.s
+++ b/libsrc/c64/emd/c64-reu.s
@@ -73,7 +73,7 @@ reu_params: .word $0000 ; Host address, lo, hi
.byte $00 ; Expansion bank no.
.word $0000 ; # bytes to move, lo, hi
.byte $00 ; Interrupt mask reg.
- .byte $00 ; Adress control reg.
+ .byte $00 ; Address control reg.
.code
diff --git a/libsrc/cbm/open.s b/libsrc/cbm/open.s
index 317f9eaa2..e9f0237cc 100644
--- a/libsrc/cbm/open.s
+++ b/libsrc/cbm/open.s
@@ -130,7 +130,7 @@ dowrite:
beq notrunc
jsr scratch
-; Complete the the file name. Check for append mode here.
+; Complete the file name. Check for append mode here.
notrunc:
lda tmp3 ; Get the mode again
@@ -168,7 +168,7 @@ nofile: ; ... else use SA=0 (read)
jsr OPEN
bcs oserror
-; Open the the drive command channel and read it
+; Open the drive command channel and read it
ldx fnunit
jsr opencmdchannel
diff --git a/libsrc/common/freopen.c b/libsrc/common/freopen.c
index d79d3cf15..41b0b094b 100644
--- a/libsrc/common/freopen.c
+++ b/libsrc/common/freopen.c
@@ -31,7 +31,7 @@ FILE* __fastcall__ freopen (const char* name, const char* mode, FILE* f)
** overwritten by _fopen.
*/
if (close (f->f_fd) < 0) {
- /* An error occured, errno is already set */
+ /* An error occurred, errno is already set */
return 0;
}
diff --git a/libsrc/common/itoa.s b/libsrc/common/itoa.s
index 176bc2ddd..808f9bc33 100644
--- a/libsrc/common/itoa.s
+++ b/libsrc/common/itoa.s
@@ -19,7 +19,7 @@ specval:
; Common subroutine to pop the parameters and put them into core
;
-dopop: sta tmp1 ; will loose high byte
+dopop: sta tmp1 ; will lose high byte
ldy #0
lda (sp),y
sta ptr2
diff --git a/libsrc/common/ltoa.s b/libsrc/common/ltoa.s
index 54b693ecc..d8d8c988d 100644
--- a/libsrc/common/ltoa.s
+++ b/libsrc/common/ltoa.s
@@ -18,7 +18,7 @@
; Common subroutine to pop the parameters and put them into core
;
-dopop: sta tmp1 ; will loose high byte
+dopop: sta tmp1 ; will lose high byte
jsr popax ; get s to ptr2
sta ptr2
stx ptr2+1
diff --git a/libsrc/dbg/dbgsupp.s b/libsrc/dbg/dbgsupp.s
index 07ab9e25a..b1f122013 100644
--- a/libsrc/dbg/dbgsupp.s
+++ b/libsrc/dbg/dbgsupp.s
@@ -58,7 +58,7 @@ DbgBreak:
.res 256
DbgStack:
-; Swap space for the the C temporaries
+; Swap space for the C temporaries
CTemp:
_DbgCS: .res 2 ; sp
diff --git a/libsrc/telestrat/gotoxy.s b/libsrc/telestrat/gotoxy.s
index ea7ed5623..3fbdc25e0 100644
--- a/libsrc/telestrat/gotoxy.s
+++ b/libsrc/telestrat/gotoxy.s
@@ -24,7 +24,7 @@ gotoxy: jsr popa ; Get Y
jsr popa
sta SCRX
-; Update adress video ram position when SCRY is modified (update_adscr)
+; Update address video ram position when SCRY is modified (update_adscr)
; Fall through
.endproc
diff --git a/libsrc/telestrat/tgi/telestrat-228-200-3.s b/libsrc/telestrat/tgi/telestrat-228-200-3.s
index 34af597eb..7eda27bc9 100644
--- a/libsrc/telestrat/tgi/telestrat-228-200-3.s
+++ b/libsrc/telestrat/tgi/telestrat-228-200-3.s
@@ -379,7 +379,7 @@ out:
tya
tax
- lda ptr3 ; XSCHAR needs in A and Y the adress of the string
+ lda ptr3 ; XSCHAR needs in A and Y the address of the string
ldy ptr3+1
BRK_TELEMON(XSCHAR)
rts
diff --git a/libsrc/telestrat/tgi/telestrat-240-200-2.s b/libsrc/telestrat/tgi/telestrat-240-200-2.s
index 345f80e0e..7a6bb8a4c 100644
--- a/libsrc/telestrat/tgi/telestrat-240-200-2.s
+++ b/libsrc/telestrat/tgi/telestrat-240-200-2.s
@@ -372,7 +372,7 @@ out:
tya
tax
- lda ptr3 ; XSCHAR needs in A and Y the adress of the string
+ lda ptr3 ; XSCHAR needs in A and Y the address of the string
ldy ptr3+1
BRK_TELEMON(XSCHAR)
rts
diff --git a/libsrc/tgi/tgi_imulround.s b/libsrc/tgi/tgi_imulround.s
index 238c69fc8..112f2930f 100644
--- a/libsrc/tgi/tgi_imulround.s
+++ b/libsrc/tgi/tgi_imulround.s
@@ -33,7 +33,7 @@ _tgi_imulround:
; ASM callable entry point
tgi_imulround:
-; Multiplicate
+; Multiply
jsr imul16x16r32
diff --git a/samples/geos/grc/Makefile b/samples/geos/grc/Makefile
index 9dd9ebc5e..ef30a6e03 100644
--- a/samples/geos/grc/Makefile
+++ b/samples/geos/grc/Makefile
@@ -53,7 +53,7 @@ test.s: test.grc
$(GRC) -s test.s test.grc
vlir.cvt: vlir.grc vlir0.s vlir1.s vlir2.s
-# using seperate calls here for demonstration purposes:
+# using separate calls here for demonstration purposes:
$(GRC) -t $(SYS) -s vlir.s vlir.grc
$(AS) -t $(SYS) vlir.s
$(AS) -t $(SYS) vlir0.s
@@ -63,7 +63,7 @@ vlir.cvt: vlir.grc vlir0.s vlir1.s vlir2.s
# you can also do the above in one command:
# $(CL) -t $(SYS) -o vlir.cvt vlir.grc vlir0.s vlir1.s vlir2.s
-
+
clean:
@$(DEL) test.s test.h 2>$(NULLDEV)
@$(DEL) vlir.s vlir.cvt vlir.c vlir.h 2>$(NULLDEV)
diff --git a/samples/multidemo.c b/samples/multidemo.c
index 396d7344a..02bb6fcac 100644
--- a/samples/multidemo.c
+++ b/samples/multidemo.c
@@ -237,7 +237,7 @@ void main (void)
/* The linker makes sure that the call to foo() ends up at the right mem
** addr. However it's up to user to make sure that the - right - overlay
- ** is actually loaded before making the the call.
+ ** is actually loaded before making the call.
*/
foo ();
}
diff --git a/samples/overlaydemo.c b/samples/overlaydemo.c
index 7553f3d0e..dde6b70ab 100644
--- a/samples/overlaydemo.c
+++ b/samples/overlaydemo.c
@@ -112,7 +112,7 @@ void main (void)
/* The linker makes sure that the call to foo() ends up at the right mem
** addr. However it's up to user to make sure that the - right - overlay
- ** is actually loaded before making the the call.
+ ** is actually loaded before making the call.
*/
foo ();
}
diff --git a/src/ca65/expr.c b/src/ca65/expr.c
index 74133d533..812b6e90c 100644
--- a/src/ca65/expr.c
+++ b/src/ca65/expr.c
@@ -1708,7 +1708,7 @@ ExprNode* GenLiteralExpr (long Val)
ExprNode* GenLiteral0 (void)
-/* Return an expression tree that encodes the the number zero */
+/* Return an expression tree that encodes the number zero */
{
return GenLiteralExpr (0);
}
diff --git a/src/ca65/expr.h b/src/ca65/expr.h
index 16dffd901..b18fabb01 100644
--- a/src/ca65/expr.h
+++ b/src/ca65/expr.h
@@ -81,7 +81,7 @@ ExprNode* GenLiteralExpr (long Val);
/* Return an expression tree that encodes the given literal value */
ExprNode* GenLiteral0 (void);
-/* Return an expression tree that encodes the the number zero */
+/* Return an expression tree that encodes the number zero */
ExprNode* GenSymExpr (struct SymEntry* Sym);
/* Return an expression node that encodes the given symbol */
diff --git a/src/ca65/lineinfo.c b/src/ca65/lineinfo.c
index e6707dac4..4f29a29d2 100644
--- a/src/ca65/lineinfo.c
+++ b/src/ca65/lineinfo.c
@@ -429,7 +429,7 @@ void ReleaseFullLineInfo (Collection* LineInfos)
/* Walk over all entries */
for (I = 0; I < CollCount (LineInfos); ++I) {
- /* Release the the line info */
+ /* Release the line info */
ReleaseLineInfo (CollAt (LineInfos, I));
}
diff --git a/src/ca65/macro.c b/src/ca65/macro.c
index d6c807035..0bdc89b5b 100644
--- a/src/ca65/macro.c
+++ b/src/ca65/macro.c
@@ -637,7 +637,7 @@ void MacUndef (const StrBuf* Name, unsigned char Style)
static int MacExpand (void* Data)
-/* If we're currently expanding a macro, set the the scanner token and
+/* If we're currently expanding a macro, set the scanner token and
** attribute to the next value and return true. If we are not expanding
** a macro, return false.
*/
diff --git a/src/ca65/studyexpr.c b/src/ca65/studyexpr.c
index 6d8734c9e..2a345a07c 100644
--- a/src/ca65/studyexpr.c
+++ b/src/ca65/studyexpr.c
@@ -711,7 +711,7 @@ static void StudyMul (ExprNode* Expr, ExprDesc* D)
*/
if (ED_IsConst (D) && ED_IsValid (&Right)) {
- /* Multiplicate both, result goes into Right */
+ /* Multiply both, result goes into Right */
ED_Mul (&Right, D);
/* Move result into D */
@@ -719,7 +719,7 @@ static void StudyMul (ExprNode* Expr, ExprDesc* D)
} else if (ED_IsConst (&Right) && ED_IsValid (D)) {
- /* Multiplicate both */
+ /* Multiply both */
ED_Mul (D, &Right);
} else {
diff --git a/src/cc65/casenode.c b/src/cc65/casenode.c
index f5e751f08..e7da64995 100644
--- a/src/cc65/casenode.c
+++ b/src/cc65/casenode.c
@@ -95,7 +95,7 @@ void FreeCaseNodeColl (Collection* Nodes)
int SearchCaseNode (const Collection* Nodes, unsigned char Key, int* Index)
/* Search for a node in the given collection. If the node has been found,
** set Index to the index of the node and return true. If the node was not
-** found, set Index the the insertion position of the node and return
+** found, set Index the insertion position of the node and return
** false.
*/
{
diff --git a/src/cc65/casenode.h b/src/cc65/casenode.h
index aef546f19..df80e62fd 100644
--- a/src/cc65/casenode.h
+++ b/src/cc65/casenode.h
@@ -116,7 +116,7 @@ void FreeCaseNodeColl (Collection* Nodes);
int SearchCaseNode (const Collection* Nodes, unsigned char Key, int* Index);
/* Search for a node in the given collection. If the node has been found,
** set Index to the index of the node and return true. If the node was not
-** found, set Index the the insertion position of the node and return
+** found, set Index to the insertion position of the node and return
** false.
*/
diff --git a/src/cc65/codegen.c b/src/cc65/codegen.c
index cf10314b9..3a98f5e63 100644
--- a/src/cc65/codegen.c
+++ b/src/cc65/codegen.c
@@ -1409,7 +1409,7 @@ static unsigned g_intpromotion (unsigned flags)
unsigned g_typeadjust (unsigned lhs, unsigned rhs)
/* Adjust the integer operands before doing a binary operation. lhs is a flags
** value, that corresponds to the value on TOS, rhs corresponds to the value
-** in (e)ax. The return value is the the flags value for the resulting type.
+** in (e)ax. The return value is the flags value for the resulting type.
*/
{
/* Get the type spec from the flags */
diff --git a/src/cc65/codegen.h b/src/cc65/codegen.h
index d6d3d2370..b0cf9858d 100644
--- a/src/cc65/codegen.h
+++ b/src/cc65/codegen.h
@@ -217,7 +217,7 @@ void g_reglong (unsigned Flags);
unsigned g_typeadjust (unsigned lhs, unsigned rhs);
/* Adjust the integer operands before doing a binary operation. lhs is a flags
** value, that corresponds to the value on TOS, rhs corresponds to the value
-** in (e)ax. The return value is the the flags value for the resulting type.
+** in (e)ax. The return value is the flags value for the resulting type.
*/
unsigned g_typecast (unsigned lhs, unsigned rhs);
diff --git a/src/cc65/expr.c b/src/cc65/expr.c
index 3b9307a37..8c1ce6bcb 100644
--- a/src/cc65/expr.c
+++ b/src/cc65/expr.c
@@ -846,7 +846,7 @@ static unsigned FunctionArgList (FuncDesc* Func, int IsFastcall, ExprDesc* ED)
/* The function returns the size of all arguments pushed onto the stack.
** However, if there are parameters missed (which is an error, and was
** flagged by the compiler), AND a stack frame was preallocated above,
- ** we would loose track of the stackpointer, and generate an internal error
+ ** we would lose track of the stackpointer, and generate an internal error
** later. So we correct the value by the parameters that should have been
** pushed into, to avoid an internal compiler error. Since an error was
** generated before, no code will be output anyway.
diff --git a/src/cl65/main.c b/src/cl65/main.c
index dba4915f2..023e111e0 100644
--- a/src/cl65/main.c
+++ b/src/cl65/main.c
@@ -538,7 +538,7 @@ static void AssembleFile (const char* File, unsigned ArgCount)
/* Check if this is the last processing step */
if (DoLink) {
/* We're linking later. Add the output file of the assembly
- ** the the file list of the linker. The name of the output
+ ** to the file list of the linker. The name of the output
** file is that of the input file with ".s" replaced by ".o".
*/
char* ObjName = MakeFilename (File, ".o");
@@ -1627,7 +1627,7 @@ int main (int argc, char* argv [])
break;
case FILETYPE_O65:
- /* Add the the object file converter files */
+ /* Add the object file converter files */
ConvertO65 (Arg);
break;
diff --git a/src/common/fp.c b/src/common/fp.c
index 0c4d2790c..0682f9f9e 100644
--- a/src/common/fp.c
+++ b/src/common/fp.c
@@ -134,7 +134,7 @@ Float FP_F_Sub (Float Left, Float Right)
Float FP_F_Mul (Float Left, Float Right)
-/* Multiplicate two floats */
+/* Multiply two floats */
{
Float D;
D.V = Left.V * Right.V;
@@ -220,7 +220,7 @@ Double FP_D_Sub (Double Left, Double Right)
Double FP_D_Mul (Double Left, Double Right)
-/* Multiplicate two floats */
+/* Multiply two floats */
{
Double D;
D.V = Left.V * Right.V;
diff --git a/src/common/fp.h b/src/common/fp.h
index 978359b8b..4e89e2316 100644
--- a/src/common/fp.h
+++ b/src/common/fp.h
@@ -102,7 +102,7 @@ Float FP_F_Sub (Float Left, Float Right);
/* Subtract two floats */
Float FP_F_Mul (Float Left, Float Right);
-/* Multiplicate two floats */
+/* Multiply two floats */
Float FP_F_Div (Float Left, Float Right);
/* Divide two floats */
@@ -129,7 +129,7 @@ Double FP_D_Sub (Double Left, Double Right);
/* Subtract two floats */
Double FP_D_Mul (Double Left, Double Right);
-/* Multiplicate two floats */
+/* Multiply two floats */
Double FP_D_Div (Double Left, Double Right);
/* Divide two floats */
diff --git a/targettest/ft.c b/targettest/ft.c
index 880df6369..3dfa0e37b 100644
--- a/targettest/ft.c
+++ b/targettest/ft.c
@@ -8,7 +8,7 @@
**
** The program asks for a filename (if it hasn't
** got one from argv). I then opens the file,
-** reads the the first 16 bytes and displays them
+** reads the first 16 bytes and displays them
** (as hex values).
** The values of sp (cc65 runtime stack pointer)
** are displayed at some places. The displayed
diff --git a/test/val/cc65150311.c b/test/val/cc65150311.c
index cd644f491..10676d679 100644
--- a/test/val/cc65150311.c
+++ b/test/val/cc65150311.c
@@ -20,7 +20,7 @@ int main(void) {
n = (p == &func);
n = (p == func);
-/* the following are not valid C and should go into seperate tests that MUST fail */
+/* the following are not valid C and should go into separate tests that MUST fail */
/*
++p;
n = (p > &func);
diff --git a/test/val/sub1.c b/test/val/sub1.c
index 5dbba97df..06e5cf463 100644
--- a/test/val/sub1.c
+++ b/test/val/sub1.c
@@ -1,5 +1,5 @@
/*
- !!DESCRIPTION!! Substraction Test
+ !!DESCRIPTION!! Subtraction Test
!!ORIGIN!! SDCC regression tests
!!LICENCE!! GPL, read COPYING.GPL
*/
diff --git a/test/val/sub2.c b/test/val/sub2.c
index 835e65733..d3ea2a05b 100644
--- a/test/val/sub2.c
+++ b/test/val/sub2.c
@@ -1,5 +1,5 @@
/*
- !!DESCRIPTION!! Substraction Test
+ !!DESCRIPTION!! Subtraction Test
!!ORIGIN!! SDCC regression tests
!!LICENCE!! GPL, read COPYING.GPL
*/
diff --git a/libsrc/tgi/tgi_clippedline.s b/libsrc/tgi/tgi_clippedline.s
index b32b819ec..b0f1dd456 100644
--- a/libsrc/tgi/tgi_clippedline.s
+++ b/libsrc/tgi/tgi_clippedline.s
@@ -159,7 +159,7 @@ tgi_clip_sign: .res 1
;----------------------------------------------------------------------------
; Multiplicate value in y/a by dy, then divide by dx.
;
.code
@@ -176,7 +176,7 @@ tgi_clip_sign: .res 1
lda tgi_clip_dy
ldx tgi_clip_dy+1 ; rhs
- jsr umul16x16r32 ; Multiplicate
+ jsr umul16x16r32 ; Multiply
; Move the result of the multiplication into ptr1:ptr2
@@ -199,7 +199,7 @@ done: bit tmp1
;----------------------------------------------------------------------------
; Multiplicate value in y/a by dx, then divide by dy.
;
.code
@@ -216,7 +216,7 @@ done: bit tmp1
lda tgi_clip_dx
ldx tgi_clip_dx+1 ; rhs
- jsr umul16x16r32 ; Multiplicate
+ jsr umul16x16r32 ; Multiply
; Move the result of the multiplication into ptr1:ptr2
@@ -159,7 +159,7 @@ tgi_clip_sign: .res 1
;----------------------------------------------------------------------------
-; Multiplicate value in y/a by dy, then divide by dx.
+; Multiply value in y/a by dy, then divide by dx.
;
.code
@@ -199,7 +199,7 @@ done: bit tmp1
;----------------------------------------------------------------------------
-; Multiplicate value in y/a by dx, then divide by dy.
+; Multiply value in y/a by dx, then divide by dy.
;
.code
diff --git a/libsrc/tgi/tgi_vectorchar.s b/libsrc/tgi/tgi_vectorchar.s
index bd4cc84c4..3e5e6a3dc 100644
--- a/libsrc/tgi/tgi_vectorchar.s
+++ b/libsrc/tgi/tgi_vectorchar.s
@@ -79,9 +79,9 @@ GetProcessedCoord:
jsr GetOp
-; Multiplicate with the scale factor.
+; Multiply with the scale factor.
- jmp tgi_imulround ; Multiplicate, round and scale
+ jmp tgi_imulround ; Multiply, round and scale
;----------------------------------------------------------------------------
; Add the base coordinate with offset in Y to the value in A/X
@@ -133,7 +133,7 @@ GetProcessedCoord:
.code
.proc _tgi_vectorchar
; Multiplicate the char value by two and save into Y
asl a
tay
@@ -133,7 +133,7 @@ GetProcessedCoord:
.code
.proc _tgi_vectorchar
-; Multiplicate the char value by two and save into Y
+; Multiply the char value by two and save into Y
asl a
tay